@@ -390,13 +390,13 @@ class RCSTool(AnnotationTool):
         self.metadata_menu = tkinter.Menu(self.menu_bar, tearoff=0)
         self.metadata_menu.add_command(label="Metaicon", command=self.metaicon_popup)
         self.metadata_menu.add_command(label="Metaviewer", command=self.metaviewer_popup)
-        self.metadata_menu.add_command(label='ValidData', command=self.show_valid_data)
-        # configure menubar
-        self.menu_bar.add_cascade(label="File", menu=self.file_menu)
-        self.menu_bar.add_cascade(label="Edit", menu=self.edit_menu)
         self._valid_data_shown = tkinter.IntVar(self, value=0)
         self.metadata_menu.add_checkbutton(
             label='ValidData', variable=self._valid_data_shown, command=self.show_valid_data)
+        # configure menubar
+        self.menu_bar.add_cascade(label="File", menu=self.file_menu)
+        self.menu_bar.add_cascade(label="Edit", menu=self.edit_menu)
+        self.menu_bar.add_cascade(label="Metadata", menu=self.metadata_menu)
         self.master.config(menu=self.menu_bar)
 
         # hide unwanted elements on the panel toolbars
