@@ -148,39 +148,30 @@ class WakeTool(WidgetPanel, WidgetWithMetadata):
         self.image_panel.hide_shapes()
 
         # define menus
-        menubar = tkinter.Menu()
+        self.menu_bar = tkinter.Menu()
         # file menu
-        filemenu = tkinter.Menu(menubar, tearoff=0)
-        filemenu.add_command(label="Open Image", command=self.callback_select_files)
-        filemenu.add_command(label="Open Directory", command=self.callback_select_directory)
-        filemenu.add_separator()
-        filemenu.add_command(label="Exit", command=self.exit)
+        self.file_menu = tkinter.Menu(self.menu_bar, tearoff=0)
+        self.file_menu.add_command(label="Open Image", command=self.callback_select_files)
+        self.file_menu.add_command(label="Open Directory", command=self.callback_select_directory)
+        self.file_menu.add_separator()
+        self.file_menu.add_command(label="Exit", command=self.exit)
         # menus for informational popups
-        popups_menu = tkinter.Menu(menubar, tearoff=0)
-        popups_menu.add_command(label="Metaicon", command=self.metaicon_popup)
-        popups_menu.add_command(label="Metaviewer", command=self.metaviewer_popup)
+        self.metadata_menu = tkinter.Menu(self.menu_bar, tearoff=0)
+        self.metadata_menu.add_command(label="Metaicon", command=self.metaicon_popup)
+        self.metadata_menu.add_command(label="Metaviewer", command=self.metaviewer_popup)
         # ensure menus cascade
-        menubar.add_cascade(label="File", menu=filemenu)
-        menubar.add_cascade(label="Metadata", menu=popups_menu)
+        self.menu_bar.add_cascade(label="File", menu=self.file_menu)
+        self.menu_bar.add_cascade(label="Metadata", menu=self.metadata_menu)
 
         # handle packing
-        primary.config(menu=menubar)
+        self.root.config(menu=self.menu_bar)
 
         # bind useful events from our canvas
         self.image_panel.canvas.bind('<<ImageIndexChanged>>', self.callback_index_changed)
-        # refreshed the canvas
-
         self.image_panel.canvas.bind('<<ShapeCoordsFinalized>>', self.callback_shape_edited)
-        # a shape is finished drawing (i.e. changed)
-
         self.image_panel.canvas.bind('<<ShapeCoordsEdit>>', self.callback_shape_edited)
-        # a shape is edited
-
         self.image_panel.canvas.bind('<<ShapeCreate>>', self.callback_shape_create)
-        # a new shape is created
-
         self.image_panel.canvas.bind('<<ShapeDelete>>', self.callback_shape_delete)
-        # a shape is deleted
 
     # callbacks for direct use
     def exit(self):
